#
# spec file for package libqmi
#
# Copyright (c) 2022-2023 ZhuningOS
#
#


%define _soname libqmi-glib5
Name:           libqmi
Version:        1.30.8
Release:        150500.1.1
# NOTE: The file headers state LESSER GPL, which is a mistake. The upstream intended license is LIBRARY GPL 2.0+
Summary:        Library to control QMI devices
License:        LGPL-2.1-or-later AND GPL-2.0-or-later
Group:          Hardware/Modem
URL:            https://www.freedesktop.org/wiki/Software/libqmi/
Source0:        https://www.freedesktop.org/software/libqmi/%{name}-%{version}.tar.xz
Source1:        https://www.freedesktop.org/software/libqmi/%{name}-%{version}.tar.xz.asc
Source98:       libqmi.keyring
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.56
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gudev-1.0) >= 232
BuildRequires:  pkgconfig(mbim-glib) >= 1.18
BuildRequires:  pkgconfig(qrtr-glib)

%description
libqmi is a glib-based library for talking to WWAN modems and devices
which speak the Qualcomm MSM Interface (QMI) protocol.

%package -n %{_soname}
Summary:        Library to control QMI devices
Group:          System/Libraries
# The tools are a useful addition
Recommends:     %{name}-tools

%description -n %{_soname}
libqmi is a glib-based library for talking to WWAN modems and devices
which speak the Qualcomm MSM Interface (QMI) protocol.

%package tools
Summary:        Helper utilities to control QMI devices
Group:          Hardware/Modem

%description tools
libqmi is a glib-based library for talking to WWAN modems and devices
which speak the Qualcomm MSM Interface (QMI) protocol.

This package contains command line tools to manage such devices.

%package devel
Summary:        Development files for the QMI device control library
Group:          Development/Languages/C and C++
Requires:       %{_soname} = %{version}

%description devel
A GLib/GIO based library to control QMI devices

This package contains files required to link sources against libqmi.

%prep
%autosetup -p1

%build
# Do not rely on env for choosing python
sed -i "s|env python$|python3|g" build-aux/qmi-codegen/*
%configure \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n %{_soname} -p /sbin/ldconfig
%postun -n %{_soname} -p /sbin/ldconfig

%files tools
%license COPYING
%doc NEWS
%{_bindir}/qmi-network
%{_bindir}/qmicli
%{_bindir}/qmi-firmware-update
# Own dirs to avoid depending on them while building
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/qmicli
%{_libexecdir}/qmi-proxy
%{_mandir}/man1/qmi-network.1%{?ext_man}
%{_mandir}/man1/qmicli.1%{?ext_man}
%{_mandir}/man1/qmi-firmware-update.1%{?ext_man}

%files -n %{_soname}
%license COPYING.LIB

%{_libdir}/libqmi-glib.so.*

%files devel
%doc AUTHORS README TODO
#Own these directories to not depend on gtk-doc
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/libqmi-glib/
%{_includedir}/libqmi-glib/
%{_libdir}/libqmi-glib.so
%{_libdir}/pkgconfig/qmi-glib.pc

%changelog
